// Guidebook UI Base 1.0
// Written by Pete Lada
// Dec 7th, 2011

/*
This will include only functions which are abstracted enough to apply to multiple different sites (i.e. Gears & Corp).
*/

if(!GBUI){
	var GBUI = {};
}

/* Tooltip
-----------------------------------------------------------------------------------------------------------*/ 


//constructor
GBUI.tooltip = function(el, options){
	
	var that = this;
	
	that.options = {
		ttClass: 'gui-tooltip',
		bottom: '5',
		layout: '<div><span></span></div>',
		zindex: 15
	}
	
	for (i in options) that.options[i] = options[i];
	
	that.start(el);
};

// Prototype
GBUI.tooltip.prototype = {
	
	start: function(el){
		var that = this,
			tip,
			pos,
			classN = that.options.ttClass;
		//that.pos = el.attr('data-tooltip-position') || 'top'
		
		that.offset = el.attr('data-tooltip-offset') || 0;
		
		that.tipColor = el.attr('data-tooltip-color') || 'default';
		
		if ( el.parents("#overlay").length == 1 ) { 
			classN += ' in-overlay';
		}
		
		that.$el = $(el);
		that.tooltip = this;
		
		that.exists = false;
		
		// Assign tips
		that.assign();
	},
	
	assign: function(){
		var that = this,
			title = that.$el.attr('title');
			
		// Remove Title Attr
		that.$el.removeAttr("title");
		
		// Show/hide TT
		that.$el.on('mouseover', function(e){
			if(that.exists === false){
				//create & layout tooltip
				that.tip = $(that.options.layout).addClass(that.options.ttClass).addClass(that.tipColor).appendTo('body').append(title);
				
				// adds in-overlay class if the tip is in an overlay
				if(that.$el.parents('.overlay').length > 0){
					that.tip.addClass('in-overlay');					
				}
				

				// indicate that element has tooltip bound to it
				that.$el.data('tooltip', that.tooltip);
				that.exists = true;
			}
			
			that.tipTimeout = setTimeout(function(){
				// in case position has changed
				pos = that.getPosition();
				//show tip
				that.tip.css({position:'absolute', left: pos.left, top: pos.top, 'z-index': that.options.zindex}).fadeIn(75, function(){
					$(document).on('click.hideTips', function(){
						that.closeTip();
					})
				});
				if(pos.position){
					that.tip.addClass(pos.position);
				}
				that.tip.hover(function() {
					that.tip.attr('hover-status', true);
				}, function() {
					that.closeTip();
					clearTimeout(that.tipTimeout);
					clearTimeout(that.offTimeout);
					that.tip.off('mouseleave.tipMouseOn');
				});
			}, 250);
		});
		
		that.$el.on('mouseout', function(e){
			that.offTimeout = setTimeout(function(){
				if(!that.tip.attr('hover-status')) {
					that.closeTip();
					clearTimeout(that.tipTimeout);
					clearTimeout(that.offTimeout);
				}
				
			}, 150);
		});
		
	},
	
	closeTip: function(){
		var that = this;
		that.tip.fadeOut(100, function(){
			$(document).off('click.hideTips');
		});
	},
	
	getPosition: function(){
		var that = this,
			left,
			position;
		var top = that.$el.offset().top +- that.tip.innerHeight() - that.options.bottom;		
		var containerRight = $('#container').offset().left+1000;
		var arrowWidth = that.tip.find('span').innerWidth();
		var arrowHeight = that.tip.find('span').innerHeight();

		if(that.$el.attr('data-tooltip-position') === 'right'){
			left = parseInt(that.$el.offset().left) + parseInt(that.offset) +(that.$el.innerWidth())+10;
			top = top + (that.tip.innerHeight()/2) + (that.$el.innerHeight()/2) + that.options.bottom;
			position = 'to-right';
			return {'top': top, 'left': left, 'position': position};
		}
		
		if(that.$el.attr('data-tooltip-position') === 'left'){
			left = parseInt(that.$el.offset().left) - parseInt(that.offset) - (that.tip.innerWidth()) - 10;
			top = top + (that.tip.innerHeight()/2) + (that.$el.innerHeight()/2) + that.options.bottom;
			position = 'to-left';
			return {'top': top, 'left': left, 'position': position};
		}
		
		if(that.$el.attr('data-tooltip-position') === 'bottom'){
			left = parseInt(that.$el.offset().left) + (that.$el.innerWidth()/2) - (that.tip.innerWidth()/2);
			top = that.$el.offset().top + that.$el.innerHeight() + arrowHeight + parseInt(that.offset);	
			position = 'to-bottom';
			return {'top': top, 'left': left, 'position': position};
		}
		
		left = parseInt(that.$el.offset().left) + (that.$el.innerWidth()/2) - (that.tip.innerWidth()/2);
		position = 'left';

		
	
		
		return {'top': top, 'left': left, 'position': position};	
	}
}

GBUI.tooltip.init = function(options){
	
	GBUI.tooltip.hideAll();
	$('[title]').each(function(){
		var $this = $(this), tt;

		if ($.trim($this.attr('tooltip')).length > 0) {
			tt = new GBUI.tooltip( $this, newOptions );
		}
	});

}

GBUI.tooltip.hideAll = function(){
	$('.gui-tooltip').hide();
}




/* Form Placeholder Text
-----------------------------------------------------------------------------------------------------------*/

/* Constructor */
GBUI.placeholder = function(el, options){
	
	var that = this;
	
	that.el = $(el);
	
	that.options = {
		color: "#666",
		zindex: 9999
	};
	
	// custom options
	for (i in options) that.options[i] = options[i];
	
	that.start();

}

/* Prototype */
GBUI.placeholder.prototype = {
	
	start: function(){
		var that = this,
			text = that.el.attr('data-placeholder');
		that.buildOverlay(text);
	},
	
	getCoords: function(){
		var that = this,
			left = that.el.position().left,
			top = that.el.position().top,
			height = that.el.outerHeight(),
			width = that.el.outerWidth();
		return({'left':left, 'top':top, 'height':height, 'width':width});
	},
	
	buildOverlay: function(text){
			
		var that = this,
			classN = 'placeholder-overlay';
		var pl = that.el.parent();
		
		// Only insert placeholder if one doesn't exist
		if( that.el.hasClass('has-placeholder') === true){
			return;
		}
		
		// sets parent container to have a relative position if it doesn't already - this allows the absolute placeholder to position correctly. 
		if(that.el.parent().css('position') !== 'absolute'){
				that.el.parent().css('position', 'relative');
		}
		
		if ( that.el.parents("#overlay").length == 1 ) { 
			classN += ' in-overlay';
		}
		
		var overlay = $('<div></div>').append('<span>' + text + '</span>').addClass(classN).prependTo(pl);

		
		if(that.el.val() !== ''){ overlay.hide(); }
		
		that.refresh(overlay);
		that.assignHelpers(overlay);
		that.el.addClass('has-placeholder');
	},
	assignHelpers: function(overlay){
		var that = this;
		// Assign focus to element (usually input)
		
		that.el.bind('focus', function(){
			setTimeout(function(){
				if(that.el.val() === ''){
					overlay.fadeTo('fast', .5);
				}
			}, 100);
		});
		
		
		overlay.bind('click',function(e){
			e.stopPropagation();
			that.el.focus();
		});
		
		that.el.bind('keyup blur', function(e){
			if(e.keyCode !== 9){
				setTimeout(function(){
					if(that.el.val() !== '')
						overlay.hide();
					else
						overlay.fadeTo('fast', 1);
				}, 100);
			}	
		});
	
		
	},
	refresh: function(overlay){
		var that = this,
		pos = that.getCoords(), 
		font = that.el.css('font-size');

		overlay.css({
			'left': pos.left,
			'top': pos.top,
			'width': pos.width,
			'height': pos.height,
			'z-index': that.options.zindex,
			'line-height': pos.height + 'px',
			'font-size': font
		});
		
		if(that.el.is('textarea') === true ){
			overlay.css({
				'line-height': 'normal',
				'top': pos.top+6+'px'
			});
		}
	}
	
	
	
};

GBUI.placeholder.init = function(options){
	$('[data-placeholder]').each(function(){
		var x = new GBUI.placeholder($(this), options);
	});
};

GBUI.placeholder.check = function(){
	$('[data-placeholder]').each(function(){
		if($(this).val() !== ''){
			$(this).parent().find('.placeholder-overlay').hide();
		}
	});
}


/* Tabs
-----------------------------------------------------------------------------------------------------------*/ 

GBUI.tabs = function(){

	var defaults = {
		direction: "horizontal",
		tabClass: "gui-tab",
		tabContainerClass: "gui-tab-container",
		el: "tabs",
		tabHeading: '',
		animation: 'none',
		minHeight: null
	},
	
	Tab = function(title, options, num, additionalClass){
		var el = options.el;
		var aClass = additionalClass || '';
		var tab = $('<div></div>').
			addClass(options.tabClass).
			addClass(aClass).
			append(title).
			attr('data-tab-id', num).
			click(function(){
				switchTabs(el, num, options);
			}).
			appendTo(options.el + ' .gui-tab-navigation');
	},
	
	switchTabs = function(parent, tabId, options){
		$(parent).find('.' + options.tabClass).each(function(){
			if(parseInt($(this).attr('data-tab-id')) === tabId){
				$(this).addClass('selected');
			}else{
				$(this).removeClass('selected');
			}
			
		});
		$(parent).find('.' + options.tabContainerClass).each(function(){
			
			var time = 0;
			if(options.animation === 'fade'){
				time = 600;
			}
			
			if(parseInt($(this).attr('data-tab-container-id')) === tabId){
				$(this).css('display', 'block');
			}else{
				$(this).css('display', 'none');
			}
			
		});
		
		window.location.hash = options.el + ':' + tabId;
	},
	
	generateTabs = function(options){
		var height;
		$(options.el).addClass(options.direction).prepend('<div class="gui-tab-navigation clearfix"></div>');
		if(options.tabHeading !== ''){
			$(options.el).find('.gui-tab-navigation').prepend('<div class="gui-tab-heading">' + options.tabHeading + '</div>');
		}
		$(options.el).find('.tab').each(function(i){
			var title = $(this).attr('data-tab-title');
			if($(this).attr('data-tab-class')){
				var tab = new Tab(title, options, i, $(this).attr('data-tab-class'));
			}else{
				var tab = new Tab(title, options, i);
			}
			$(this).addClass(options.tabContainerClass).attr('data-tab-container-id', i).css('display', 'none');
			if(!options.minHeight && height < $(this).innerHeight() + $(options.el).find('.gui-tab-navigation').height() || !height){
				height = $(this).innerHeight() + $(options.el).find('.gui-tab-navigation').height();
			}
			if(options.minHeight){
				height = options.minHeight + $(options.el).find('.gui-tab-navigation').height();
			}
			$(this).find('.next-tab').click(function(e){
				e.preventDefault();
				switchTabs(options.el, i+1, options);
				$('.gui-tooltip').hide();
			});
			if(i === $(options.el).find('.tab').length - 1){
				$(options.el).css('min-height', height);
			}
		});
		
		if(window.location.hash.indexOf(options.el) > -1){
			var tabid = window.location.hash.split(':');
			switchTabs(options.el, parseInt(tabid[1]), options);
		}else{
			switchTabs(options.el, 0, options);	
		}
	},
	
	init = function(options){
		var newOptions = $.extend(defaults, options);
		generateTabs(newOptions);
	};
	
	return init;
	
}();



/* Twitter
-----------------------------------------------------------------------------------------------------------*/ 

GBUI.twitter = function(){
	
	var defaults = {
		account: 'guidebook',
		count: 1,
		el: 'document.body',
		layout: '<div></div>',
		tweetClass: 'tweet',
		loadingText: 'Loading TweetsÃ¢â‚¬Â¦'
	},
	
	// regex to create links within the twitter text (links urls and @usernames)
	createLinks = function(text) {
		var url_regexp = /(ftp|http|https):\/\/(\w+:{0,1}\w*@)?(\S+)(:[0-9]+)?(\/|\/([\w#!:.?+=&%@!\-\/]))?/;
		var linkedText = text.replace( url_regexp, '<a target="_blank" href="$1://$2$3$4$5$6">$1://$2$3$4$5$6</a>');
		linkedText = linkedText.replace(/(^|\s)@(\w+)/g, '$1<a target="_blank" href="http://www.twitter.com/$2">@$2</a>');
		return linkedText;
	},
	
	// Tweet class
	Tweet = function(text, options){
		var l = $(options.layout).addClass(options.tweetClass).appendTo(options.el).append(createLinks(text));
	},
	
	getTweets = function(options){
		var url='http://search.twitter.com/search.json?callback=?&q=from%3A' + options.account + '&include_entities=true';

		$.getJSON(url,function(json){
			$(options.el).html('');
			$.each(json.results, function(i,tweet){
				if(i<=options.count-1){
					var t = new Tweet(tweet.text, options);
				}
			});
			
		});
	},
	
	init = function(options){
		var newOptions = $.extend(defaults, options);
		var loading = $('<div></div>').append(newOptions.loadingText).appendTo(options.el);
		getTweets(newOptions);
	};
	
	return init;
	
}();


function getUrlVars(url)
{
	if(url){
	    var vars = [], hash;
	    var hashes = url.slice(url.indexOf('?') + 1).split('&');
	    for(var i = 0; i < hashes.length; i++)
	    {
	        hash = hashes[i].split('=');
	        vars.push(hash[0]);
		
	        vars[hash[0]] = hash[1];
	    }
	    return( vars );
	}
}


/*  Overlay refactored
-----------------------------------------------------------------------------------------------------------*/

GBUI.overlayHistory = []; // overlay history array, used for opening multiple overlays and needing to go back

;(function ( $, window, document, undefined ) {

	var defaults = {
		exposeColor: '#fff',
		overlayClass: '',
		loadingClass: 'item loading',
		loadingText: 'Loading...',
		animation: 'none',
		layout: '<div class="overlay-expose"><div class="overlay"><div class="overlay-content clearfix"></div></div></div>',
		isSideLoaded: false,
		displayType: 'default'
	};
		
	function gbuiOverlay(el, options){
		var that = this;
		that.el = el;
		that.obj = this;
		that.$el = $(that.el);
		that.init(options);
	};
	
	
	gbuiOverlay.prototype = {

		init: function(options){
			var that = this;
			that.settings = $.extend({}, defaults, options);
			that.$el = $(that.el);
			
			if(that.$el.parents('.overlay').length > 0) that.settings.isSideLoaded = true;
			that.refresh();
		},
		
		refresh: function(){
			var that = this;
			that.$el.on('click.openOverlay', function(e){
				e.preventDefault();
				if(that.$el.parent().attr('rel') === 'overlay') {
					e.stopPropagation();
				}
				that.open();
			});
		},
		
		getTrigger: function(){
			var that = this;
			return that.el;
		},
		
		getOverlay: function(){
			var that = this;
			if(that.overlay && that.overlay !== undefined){
				return that.overlay;
			}
			return false;
		},
		
		open: function(){
			var that = this;
			if(GBUI.overlayHistory.length > 0){
				GBUI.overlayHistory[GBUI.overlayHistory.length - 1].getOverlay().fadeOut(0);
			}
			that._buildOverlay();
			return that.overlay;
		},
		
		_buildOverlay: function(){
			var that = this;
			that.overlay = $(that.settings.layout).addClass(that.settings.overlayClass).attr('id','overlay').appendTo(document.body).show();
			that.settings.displayType = that.$el.attr('data-overlay-type') || 'default';
			
			if(that.settings.displayType === 'popover'){
				that.overlay.css({
					'visibility':'hidden'
				});
			}
			
			that._getMaxSize();
			that._load();
		},
		
		_load: function(){
			var that = this,
				loading = $('<div></div>').append(that.settings.loadingText).addClass(that.settings.loadingClass).appendTo(that.overlay.find('.overlay-content'));
			
			$('body').addClass('has-overlay');
			
			// set up overlay background if in theater mode
			if(that.settings.displayType === 'theater'){
				$('body').addClass('theater-mode');
				that.overlay.find('.overlay-expose').append('<div class="overlay-bgd"></div>');
				$('<div class="overlay-bgd"></div>').appendTo($(that.overlay).find('.overlay'));
			}
			
			if(that.settings.displayType === 'video'){
				$('body').addClass('theater-mode video');
				that.overlay.find('.overlay-expose').append('<div class="overlay-bgd"></div>');
				$('<div class="overlay-bgd"></div>').appendTo($(that.overlay).find('.overlay'));
			}
			
			else if(that.settings.displayType === 'popover'){
				that.overlay.addClass('popover');
				that._setPosition();
			}else{
				$('body').removeClass('theater-mode video');
			}
			
			// store overlay in history
			GBUI.overlayHistory.push(that.obj);
			that._assignEscape();
			
			//get url vars
			GBUI.parameters = getUrlVars($(that.getTrigger()).attr("href"));
			
			// refresh / load overlay content
			that._refreshContent(function(data){
				$(loading).remove();
				
				if(that.settings.displayType === 'popover'){
					that._setPosition();
				}
	
				
			});
			
		},
		
		_assignEscape: function(){
			var that = this;
			
			// remove keydown event in case it was added already
			$(document).off('keydown.closeOverlay');
			
			// close overlay on escape
			$(document).on('keydown.closeOverlay', function(event){
				if(event.keyCode === 27){
					// if we're not at the first overlay, closes the current overlay (last opened)
					if(GBUI.overlayHistory.length > 0){
						var o = GBUI.overlayHistory[GBUI.overlayHistory.length-1];
						o.close();
					// else, close self
					}else{
						that.close();
					}
				}
			});
		},
		
		_refreshContent: function(complete){
			var that = this,
				url = that.$el.attr('href');
			
			if(!url || url === undefined){
				url = that.$el.attr('data-url');
			}
			
			$.ajax({
				url: url,
				complete: function(data){
					if(data.statusText === 'error'){
						that.overlay.find('.overlay-content').html('<div class="' + that.settings.loadingClass + '"><p>Uh oh, something went wrong! We\'re working on fixing this. <br/><br/><a href="#" class="close">Close overlay and try again.</a></p></div>');
						that._createClose();
					}else{
						that.overlay.find('.overlay-content').html(data.responseText);
						
						that.overlay.addClass('ready');
						that._createClose();

						// set max size for overlay if not theater
						that._setResizeListener();

						// check for new overlays
						$('[rel=overlay]').gbuiOverlay();

						// check for new tooltips
						GBUI.tooltip.init({
							bottom: 10,
							zindex: 1000
						});

						//refresh scroll height
						if($('.overlay .scroll').data('fauxscroll')){
							$('.overlay .scroll').data('fauxscroll').createScroll();
						}
						
					}
					
					complete(data);
					
				}
			});
			
			
		},
		
		_setResizeListener: function(){
			var that = this;
			$(window).on('resize.resizeOverlay', function(){
				resize();
			});
			function resize(){
				if(that._getMaxUsableSize() < that._getContentHeight() && that.settings.displayType !== 'theater'){
					$(that.overlay).find('.scroll-container').css({
						'max-height': that._getMaxUsableSize() + 'px',
						'min-height': '100px'
					});
				}
			}
			resize();
		},

		_getContentHeight: function(){
			return $(this.overlay).find('.scroll-container').prop('scrollHeight');
		},
		
		_getMaxSize: function(){
			return $(window).innerHeight();
		},

		_getMaxUsableSize: function(){
			return $(window).innerHeight() - 50 - 108 - 95;
		},
		
		_createClose: function(){
			var that = this;
			that.overlay.find('.close').on('click', function(e){
				e.preventDefault();
				$('#' + e.target.id).trigger('click.bb-overlay-view');
				that.close(that.settings);
			});
			
			if(GBUI.overlayHistory.length > 1){
				that.overlay.find('.close').html('&larr; back');
			}
			
		},
		
		close: function(options){
			var that = this;
			// remove last opened overlay from history
			GBUI.overlayHistory.pop();
			
			that.overlay.addClass('closing');
			
			setTimeout(function(){
				
				that.overlay.remove();
				// if all overlays are closed (no history), remove all overlay classes
				if(GBUI.overlayHistory.length === 0){
					$('body').removeClass('theater-mode video has-overlay');
					$(document).off('keydown.closeOverlay');
				}
				that.overlay = null;

				// close & remove all tooltips associated with the overlays
				$('.gui-tooltip.in-overlay').remove();
				
			}, 300);
			
			
			// if there are more overlays to deal with...
			if(GBUI.overlayHistory.length > 0){
				//grab previous overlay
				var o = GBUI.overlayHistory[GBUI.overlayHistory.length-1];
				
				// set display state to theater or normal 
				if(o.settings.displayType !== 'theater'){
					$('body').removeClass('theater-mode video');
				}else{
					$('body').addClass('theater-mode');
				}
				$('body').addClass('has-overlay');
				
				// fade in previous overlay in history
				o.getOverlay().show();

				if(!options || options.refresh === true){
					// refresh its content 
					o._refreshContent(function(data){
					});
				}
			}
		},
		
		_createArrow: function(overlay){
			var that = this
			if(!that.arrow){
				that.arrow = $('<span/>').addClass('arrow');
			}
			that.arrow.css({
				top: ((overlay.innerHeight()/2) - 7) + 'px'
			});
			
			if( overlay.find('.arrow').length <= 0 ){
				overlay.prepend(that.arrow);
			}
		},
		
		_setPosition: function(){		
			var that = this;
			var pos = that._getPosition();
			var $overlay = that.getOverlay().find('.overlay');
			
			var containerLeft = $('#content').offset().left;
			
			var left = pos.left - $overlay.innerWidth();
			var top = pos.top - ($overlay.innerHeight()/2) + (pos.height/2); 
			
			var browserBottom = $(window).scrollTop() + $(window).height();
			
			if(left < containerLeft){
				left = pos.left + pos.width;
				$overlay.addClass('to-right');
			}
			
			
			if( (top + $overlay.innerHeight()) > browserBottom  ){
				$(window).scrollTo((top + $overlay.innerHeight() - browserBottom), 200, function(){
					that._setPosition();
					that.overlay.css({
						'visibility':'visible'
					});
				});
			}else{
				that.overlay.css({
					'visibility':'visible'
				});
			}
			
			$overlay.css({
				'left': left,
				'top': top
			});

			
			that._createArrow($overlay);
		},
		
		_getPosition: function(){
			var that = this,
				$trigger = $(that.getTrigger());
				
			var left = $trigger.offset().left;
			var top = $trigger.offset().top - $(window).scrollTop();
			var width = $trigger.innerWidth();
			var height = $trigger.innerHeight();
			
			return {
				'left': left,
				'top': top,
				'width': width,
				'height': height
			}
		},
		
		_getArrowPosition: function(){
			var that = this;
			var pos = that._getPosition();
		},
		
		destroy: function(){
			var that = this;
			var trigger = that.getTrigger();
			$(trigger).removeData('overlay').off('click.openOverlay');

			return that;
		}

	};
	$.fn['gbuiOverlay'] = function(options){
		var that = this;
		if( typeof options === 'string'){
			if( gbuiOverlay.prototype[options]){				
				return gbuiOverlay.prototype[ options ].apply($(this).data('overlay'));
			}
			
		}
		
		this.each(function() {
			if( !$(this).data('overlay') ){
				$(this).data('overlay', new gbuiOverlay(this, options ));
			}
		});
		
		return this;
	}
	
	
})( jQuery, window, document );

/* Rotating Content with paging indicators
-----------------------------------------------------------------------------------------------------------*/ 

GBUI.rotate = function(){
	var settings, currentIndex = 0, heroes = [], timer, active = true,
	defaults = {
		el: '#hero',
		delay: 3000,
		animationSpeed: 700,
		pagingIndicators: true,
		navButtons: false
	},
	
	Hero = function(el, id){
		$(el).attr('data-rotate-id', id);
		heroes.push(id);
	},
	
	verifyId = function(id){
		if(id < heroes.length){
			return true;
		}else{
			return false;
		}
	},
	
	PagingIndicator = function(el, paging, id){
		var title = '',	
			p = $('<a>&bull;</a>');
		
		if(el.attr('data-title')){
			title = el.attr('data-title');
			p.attr('title', title);
		}
		
		p.click(function(){
			if(currentIndex === id){
				return;
			}
			clearTimeout(timer);
			if(active !== true){
				rotate(id);
			}
		}).attr('data-rotate-id', id).appendTo(paging);
	},
	
	changeIndicator = function(id){
		var holder = settings.pagingHolder || settings.el;
		$(holder).find('.paging-navigation a').each(function(){
			if(parseInt($(this).attr('data-rotate-id')) === id){
				$(this).addClass('selected');
			}else{
				$(this).removeClass('selected');
			}
		});
	}, 
	
	rotate = function(to){
		
		
		if(to === heroes.length){
			to = 0;
		}
		if(to < 0){
			to = heroes.length-1;
		}
		
		changeIndicator(to);
		active = true;
		
		$(settings.el).find('.item-rotate').each(function(){
		
			if($(this).css('display') === 'block'){
				$(this).fadeOut(settings.animationSpeed);
			}
		
			if(parseInt($(this).attr('data-rotate-id')) === to){
				$(this).fadeIn(settings.animationSpeed, function(){
					currentIndex = to;
					timer = setTimeout(function(){
						if(verifyId(to+1) === true){
							clearTimeout(timer);
							rotate(to+1);
						}else{
							clearTimeout(timer);
							rotate(0);
						}
					}, settings.delay);
					active = false;
				});
			}
		});
	},
	
	createNavButtons = function(){
		var $prev = $('<a></a>'), $next = $('<a></a>'),
			holder = settings.pagingHolder || settings.el;
		$prev.addClass('previous nav-button');
		$next.addClass('next nav-button');
		
		$(holder).append($prev,$next);
		
		$prev.on('click', function(){
			clearTimeout(timer);
			if(!active)
				rotate(currentIndex-1);
		});
		$next.on('click', function(){
			clearTimeout(timer);
			if(!active)
				rotate(currentIndex+1);
		});
		
	},
	
	
	
	createPagingHolder = function(){
		var holder = settings.pagingHolder || settings.el;
		var x = $('<div></div>').addClass('paging-navigation').appendTo(holder);
		return x;
	},
	
	init = function(options){
		heroes = [], currentIndex = 0;
		clearTimeout(timer);
		settings = $.extend(defaults, options);
		var paging = createPagingHolder();
		$(settings.el).find('.item-rotate').each(function(i){
			var t = new Hero($(this), i);
			if(settings.pagingIndicators === true){
				var x = new PagingIndicator($(this), paging, i);
			}
		});
		
		if(settings.navButtons === true){
			createNavButtons();
		}
		
		rotate(0);
		
	};
	
	return init;
	

}();

/*  Google map object
   -----------------------------------------------------------------------------------------------------------*/

GBUI.initMap = function(el, address, options){


	var map,
	geocoder;


	function initialize() {
		var myLatlng;
		var defaults = {
			zoom: 15,
			center: myLatlng,
			mapTypeId: google.maps.MapTypeId.ROADMAP,
			mapTypeControl: false,
			navigationControlOptions: {
			    style: google.maps.NavigationControlStyle.SMALL
			  },
			backgroundColor:'white'
		}
		geocoder = new google.maps.Geocoder();
		map = new google.maps.Map(document.getElementById(el), defaults);

		function codeAddress() {
			geocoder.geocode( { 'address': address}, function(results, status) {
				if (status == google.maps.GeocoderStatus.OK) {	
					map.setCenter(results[0].geometry.location);
					var marker = new google.maps.Marker({
						map: map,
						position: results[0].geometry.location
					});
					
					if(options.success){
						options.success();
					}
					
					
				} else {
					if(options.failure){
						options.failure();
					}
				}
			});
		}

		codeAddress();

		var marker = new google.maps.Marker({
			position: myLatlng,
			map: map,
			title:"Venue Location"
		});
	}


	initialize();	
}


/* Phone Nav
-----------------------------------------------------------------------------------------------------------*/

GBUI.podNav = function(options){
	
	var that = this;
	
	that.defaults = {
		container: '',
		selectEvent: "hover",
		podSelectedClass: 'selected',
		podDeselectedClass: '',
		itemSelectedClass: 'showing'
	};
	
	that.init(options);
	
};
	
GBUI.podNav.prototype = {
			
	init: function(options){
		var that = this;
		that.settings = $.extend({}, that.defaults, options);
		that.$container = $(that.settings.container),
			that.$navs = that.$container.find('.nav-pod'),
			that.$items = that.$container.find('.nav-item');
			
		that.showInitial();
		that.setupNav();
		that.$container.addClass('loaded');
	},
	
	showInitial: function(){
		var that = this;
		that.$items.first().addClass(that.settings.itemSelectedClass);
		that.setSelectedNav(that.$navs.first());
	},
	
	setupNav: function(){
		var that = this;
		that.$navs.each(function(i){
			$(this).on(that.settings.selectEvent, function(e){
				e.preventDefault();
				if($(this).hasClass(that.settings.podSelectedClass)){
					return false;
				}
				that.showItem( that.$items[i] );
				that.setSelectedNav(this);
			});
		});
	},
	
	showItem: function(item){
		var that = this;
		that.$items.removeClass('leaving').filter('.showing').addClass('leaving');
		that.$items.removeClass(that.settings.itemSelectedClass);
		$(item).addClass(that.settings.itemSelectedClass);
	},
	
	setSelectedNav: function(navItem){
		var that = this;
		that.$navs.removeClass(that.settings.podSelectedClass).addClass(that.settings.podDeselectedClass);
		$(navItem).addClass(that.settings.podSelectedClass).removeClass(that.settings.podDeselectedClass);
	}
	
}



/*  Toggle
-----------------------------------------------------------------------------------------------------------*/


;(function ( $, window, document, undefined ) {

	var defaults = {
		itemContainer: '',
		itemClass: '.toggle-item',
		animationClass: null
	};
		
	function gbuiToggle(toggleEl, options){
		var that = this;
		that.el = toggleEl;
		that.obj = this;
		that.$el = $(that.el);
		that.init(options);
	};
	
	
	gbuiToggle.prototype = {

		init: function(options){
			var that = this;
			that.settings = $.extend({}, defaults, options);
			that.$el = $(that.el);
			
			that.start();
		},
		
		start: function(){
			var that = this;
			that.$container = $(that.settings.itemContainer);
			that.$container.find(that.settings.itemClass).css({
				visibility: 'hidden'
			});
			var current = that._getToggleIndex() || 0; // figure out which toggle is selected
			that.toggleTo(current);
			that._assignClicks();
		},
		
		
		toggleTo: function(index){
			var that = this;
			that.$container.find(that.settings.itemClass).each(function(i){
				var $el = $(this);
				$el.css('visibility', 'hidden');
				if(that.settings.animationClass){
					$el.removeClass(that.settings.animationClass);
				}
				if(i === index){
					if(that.settings.animationClass){
						$el.addClass(that.settings.animationClass);
					}
					$el.css('visibility', 'visible');
				}
			});
			that.$el.find('a').removeClass('selected');
			that.$el.find('a:eq(' + index + ')').addClass('selected');
		},
		
		_getToggleIndex: function(){
			var that = this;
			that.$el.find('a').each(function(i){
				if($(this).hasClass('selected')){
					return i;
				}
			});
			return false;
		},
		
		_assignClicks: function(){
			var that = this;
			that.$el.find('a').each(function(i){
				$(this).on('click', function(e){
					e.preventDefault();
					that.toggleTo(i);
				});
			})
		}

	};
	
	$.fn['gbuiToggle'] = function(options){
		var that = this;
		if( typeof options === 'string'){
			if( gbuiToggle.prototype[options]){				
				return gbuiToggle.prototype[ options ].apply($(this).data('toggle'));
			}	
		}
		
		this.each(function() {
			if( !$(this).data('toggle') ){
				$(this).data('toggle', new gbuiToggle(this, options));
			}
		});
		
		return this;
	}
	
	
})( jQuery, window, document );



















